import os
import json
import unittest
import flask

from pprint import pprint

from p2.ui.app import app

class TestApp(unittest.TestCase):

    def setUp(self):
        self.app = app
        self.app.testing = True
        self.client = self.app.test_client()

    def test_js(self):
        with self.app.test_client() as c:
            resp = c.get('/api/js')
            self.assertGreater(len(resp.data), 0)
            pprint(resp.data)

    def test_main_template(self):
        with self.app.test_client() as c:
            resp = c.get('/')
            self.assertIsNotNone(resp)
            pprint(resp.data)

    def test_select(self):
        params = json.dumps(dict(
            filter=dict(component='p2.scheduler'),
            sort='component desc',
            limit=10
        ))

        with self.app.test_client() as c:
            resp = c.post('/select/config', data=json.dumps({'params': params}))
            self.assertEqual(resp.status_code, 200)
            records = resp.json
            self.assertEqual(len(records), 1)

    def test_update_on_conflict(self):
        with self.app.test_client() as c:
            params = json.dumps(dict(
                conflicting_cols=['exp_id'],
                record=dict(
                    exp_id='1',
                    load_injectors=True,
                    notes="this should be a new record..."
                )
            ))
            resp = c.post('/update_on_conflict/session_report', data=json.dumps({'params': params}))
            self.assertEqual(resp.status_code, 200)
            resp = resp.json
            self.assertEqual(resp, 1)

            params = json.dumps(dict(
                filter=dict(exp_id='1'),
                sort='exp_id desc',
                limit=10
            ))

            resp = c.post('/select/session_report', data=json.dumps({'params': params}))
            self.assertEqual(resp.status_code, 200)
            records = resp.json
            self.assertEqual(len(records), 1)
            self.assertEqual(records[0]['notes'], "this should be a new record...")

            params = json.dumps(dict(
                conflicting_cols=['exp_id'],
                record=dict(
                    exp_id='1',
                    notes="this should be an updated one..."
                )
            ))
            resp = c.post('/update_on_conflict/session_report', data=json.dumps({'params': params}))
            self.assertEqual(resp.status_code, 200)
            resp = resp.json
            self.assertEqual(resp, 1)

            params = json.dumps(dict(
                filter=dict(exp_id='1'),
                sort='exp_id desc',
                limit=10
            ))
            resp = c.post('/select/session_report', data=json.dumps({'params': params}))
            self.assertEqual(resp.status_code, 200)
            records = resp.json
            self.assertEqual(len(records), 1)
            self.assertEqual(records[0]['notes'], "this should be an updated one...")

