#!/home/jenkins/home/workspace/p2/p2.ui/p2.ui/p2.ui/venv/bin/python3
import os, sys
sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

import click
from p2.tools.prepare_db import createDB, createDB_from_schema, \
        destroyDB, \
        check_updates, \
        commit_update, \
        set_db_name, \
        setUpDB

@click.group()
def cli():
    pass

@cli.command(help="Creates the db with the passed name as a copy of p2store template")
@click.option('--name', required=True, help='the database name')
def create_db(name):
    print(f"Going to create db {name}")
    set_db_name(name)
    createDB_from_schema(name)

@cli.command(help="Prints the first update file not yet applied or a void string")
@click.option('--updates_dir', required=False, help='the update files directory')
@click.option('--updates_file', required=False,
              help='the csv file with the list of applied updates')
def check_for_updates(updates_dir, updates_file):
    print(check_updates())

@cli.command(help="Updates the csv file")
@click.option('--updates_file', required=False,
              help='the csv file with the list of applied updates')
@click.option('--file', required=True, help='the update file to be committed')
def commit_updates(updates_file, file):
    print(f"Going to commit update file {file}")
    commit_update(updates_file, file)

@cli.command(help="Destroys the db with the passed name")
@click.option('--name', required=True, help='the database name')
def destroy_db(name):
    print(f"Going to destroy db {name}")
    set_db_name(name)
    destroyDB(name)

@cli.command(help="Populate db pointed to by DB_P2STORE_DBNAME")
def set_up_db():
    setUpDB()

if __name__ == "__main__":
    cli()
