#!/home/jenkins/home/workspace/p2/p2.ui/p2.ui/p2.ui/venv/bin/python3
import os
import logging

from werkzeug.debug import DebuggedApplication
from werkzeug.middleware.dispatcher import DispatcherMiddleware
from werkzeug.middleware.shared_data import SharedDataMiddleware
from werkzeug.exceptions import NotFound
from flask import Flask
from flask_cors import CORS

import p2.ui.settings
from p2.ui.app import app as main
from p2.tools.driver import get_attr

logging.basicConfig(level=logging.DEBUG)

app = Flask(__name__)
CORS(app)
app.config.from_object('p2.ui.settings')
if os.getenv('P2_UI_SETTINGS'):
    app.config.from_envvar('P2_UI_SETTINGS')

app.logger.info("Registered apps: {}".format(app.config['REGISTERED_APPS']))


@app.route('/')
def index():
    return "All good"

mounts = dict()
for registered_app in app.config['REGISTERED_APPS']:
    mounts['/'+registered_app] = get_attr(
        driver='app',
        module='p2.ui.'+registered_app,
        attr_name='app'
    )

mounts['/main'] = main
app.wsgi_app = DispatcherMiddleware(app.wsgi_app, mounts=mounts)

if __name__ == '__main__':
    app.run( debug=True )
